import React from "react";

import style from "./Resume.module.css";
import { markdownToHtml } from "@/services/content-service";
import { MDXClient } from "next-mdx-remote-client/csr";
import Link from "next/link";

function Resume({
  introMdxSource,
  competencies,
  education,
  certifications,
  languages,
  experience,
}) {
  return (
    <div className={style.cv}>
      <ol className="hide-print">
        <li>
          <a href="#experience">Professional experience</a>
        </li>
        <li>
          <a href="#competencies">Competencies</a>
        </li>
        <li>
          <a href="#competencies">Certifications</a>
        </li>
        <li>
          <a href="#languages">Languages</a>
        </li>
        <li>
          <a href="#education">Education</a>
        </li>
      </ol>
      <div>
        <div className={style.about}>
          <MDXClient {...introMdxSource} />
          <span className="print-only">
            See more at <a href="https://aaronjy.me/cv">aaronjy.me/cv</a>
          </span>
        </div>
      </div>
      <div className={style.cvContent}>
        <div className={style.experience}>
          <h2 id="experience">Professional experience</h2>

          {experience?.map((exp, i) => (
            <div key={i}>
              <WorkExperience
                employer={exp.employer}
                position={exp.position}
                start={exp.start}
                end={exp.end}
              >
                {markdownToHtml(exp.description)}
              </WorkExperience>
              {!!exp.skills?.length && (
                <details className="hide-print">
                  <summary>Competencies</summary>
                  <>{exp.skills.sort().join(", ")}</>
                </details>
              )}
            </div>
          ))}
        </div>
        <div className={style.sidebar}>
          <h2 id="competencies">Competencies</h2>
          <ul>
            {competencies
              ?.sort((a, b) => a.name - b.name)
              .map((c, i) => (
                <li key={i}>{c.name}</li>
              ))}
          </ul>

          <h2 id="certifications">Certifications</h2>
          <ul>
            {certifications
              ?.sort((a, b) => a.name > b.name)
              .map((c, i) => (
                <li key={i}>{c.name}</li>
              ))}
          </ul>

          <h2 className="languages">Languages</h2>
          <ul>
            {languages?.sort().map((c, i) => (
              <li key={i}>
                <strong>{c.name}</strong> - {c.proficiency}
              </li>
            ))}
          </ul>

          <h2 className="education">Education</h2>
          <ul>
            {education
              ?.sort((a, b) => a.name - b.name)
              .map((c, i) => (
                <li key={i}>{c.name}</li>
              ))}
          </ul>
        </div>
      </div>
    </div>
  );
}

export default Resume;

function WorkExperience({ position, employer, start, end, children }) {
  return (
    // <div className={style["work-experience"]}>
    //   <div>
    //     <h3 id={position}>
    //       {position}
    //       <br />
    //       <small>{employer}</small>
    //     </h3>
    //     <small>
    //       <time>{start}</time> - <time>{end}</time>
    //     </small>
    //   </div>
    //   <div
    //     data-test="children"
    //     dangerouslySetInnerHTML={{ __html: children }}
    //   />
    // </div>

    <table className={style.experienceTable}>
      <tbody>
        <tr>
          <td>
            <span id={position} className={style.position}>
              {position}
            </span>
            <br />
            <span className={style.employer}>{employer}</span>
          </td>
          <td className="text-right">
            {/* <small> */}
            <time>{start}</time> - <time>{end}</time>
            {/* </small> */}
          </td>
        </tr>
        <tr>
          <td colSpan={2}>
            <div
              data-test="children"
              dangerouslySetInnerHTML={{ __html: children }}
            />
          </td>
        </tr>
      </tbody>
    </table>
  );
}
