import StaticContentList from "@/components/StaticContentList/StaticContentList";
import { fetchPosts } from "@/services/content-service";
import { useEffect, useState, useTransition } from "react";

export const mdxComponents = {
  StaticContentList: ({ type, urlPrefix, max = 0 }) => {
    const [items, setItems] = useState([]);
    const [isLoading, setLoading] = useState(false);

    useEffect(
      function () {
        if (!urlPrefix || max <= 0) return;

        switch (type) {
          case "posts":
            (async function () {
              setLoading(true);
              const res = await fetchPosts([]);
              const json = await res.json();
              setItems(
                json.data.sort((a, b) => a.datePublished < b.datePublished) ??
                  [],
              );
              setLoading(false);
            })();
            break;

          default:
            throw `Could not render StaticContentList: content type ${type} not supported.`;
        }
      },
      [type, urlPrefix, max],
    );

    return (
      <>
        {isLoading && <p>Loading...</p>}
        {!isLoading && (
          <StaticContentList entries={items} urlPrefix={urlPrefix} max={max} />
        )}
      </>
    );
  },
};
