import Resume from "@/components/Resume/Resume";
import { FailedFetchCVError } from "@/errors";
import DefaultLayout from "@/layouts/DefaultLayout/DefaultLayout";
import { fetchCV } from "@/services/content-service";
import { NextSeo } from "next-seo";

import style from "./cv.module.css";
import { serialize } from "next-mdx-remote-client/serialize";

export const Title = "CV";

export async function getStaticProps() {
  const res = await fetchCV([]);

  if (!res.ok) {
    throw new FailedFetchCVError(await res.text());
  }

  const cv = (await res.json()).data;
  if (!cv) {
    return {
      notFound: true,
      revalidate: 60,
    };
  }

  const {
    intro,
    competencies,
    education,
    languages,
    certifications,
    experience,
  } = cv;

  const introMdxSource = await serialize({ source: intro });

  return {
    props: {
      introMdxSource,
      competencies,
      education,
      languages,
      certifications,
      experience,
    },
    revalidate: 60,
  };
}

export default function ResumePage({
  introMdxSource,
  competencies,
  education,
  certifications,
  languages,
  experience,
}) {
  return (
    <DefaultLayout>
      <NextSeo
        title={Title}
        openGraph={{
          title: Title,
        }}
      />
      <h1 className="hide-print">{Title}</h1>
      <h1 className={`${style.printHeading} print-only`}>Aaron Yarborough</h1>
      <section>
        <Resume
          introMdxSource={introMdxSource}
          competencies={competencies}
          education={education}
          certifications={certifications}
          languages={languages}
          experience={experience}
        />
      </section>
    </DefaultLayout>
  );
}
