import BookReviewItem from "@/components/BookReviewItem/BookReviewItem";
import Grid from "@/components/Grid/Grid";
import { FailedFetchBookReviewsError } from "@/errors";
import DefaultLayout from "@/layouts/DefaultLayout/DefaultLayout";
import { stringifyAndParse } from "@/lib/helpers";
import { fetchBookReviews } from "@/services/content-service";
import { NextSeo } from "next-seo";

export const Title = "Library";

export async function getStaticProps() {
  const res = await fetchBookReviews();

  if (!res.ok) {
    throw new FailedFetchBookReviewsError(await res.text());
  }

  const reviews = (await res.json()).data.sort(
    (a, b) => new Date(b.readDate).getTime() - new Date(a.readDate).getTime(),
  );

  return {
    props: {
      reviews: stringifyAndParse(reviews),
    },
    revalidate: 60,
  };
}

export default function Library({ reviews }) {
  return (
    <DefaultLayout>
      <NextSeo
        title={Title}
        openGraph={{
          title: Title,
        }}
      />

      <h1>{Title}</h1>

      <section>
        <Grid columns={5}>
          {reviews.map((review, _) => (
            <BookReviewItem
              key={review.title}
              {...review}
              href={`/library/${review.slug}`}
            />
          ))}
        </Grid>
      </section>
    </DefaultLayout>
  );
}
