import {
  fetchBasicPages,
  fetchBookReviews,
  fetchPosts,
} from "@/services/content-service";
import { getServerSideSitemapIndexLegacy } from "next-sitemap";

const siteUrl = process.env.SITE_URL || "https://www.aaronjy.me";

export const getServerSideProps = async (ctx) => {
  const [basicPagesResp, bookReviewsResp, postsResp] = await Promise.all([
    fetchBasicPages().then((res) => res.json()),
    fetchBookReviews().then((res) => res.json()),
    fetchPosts().then((res) => res.json()),
  ]);

  const urls = [
    ...basicPagesResp.data.map((entry) => `${siteUrl}/${entry.path ?? ""}`),
    ...bookReviewsResp.data.map(
      (entry) => `${siteUrl}/library/${entry.slug ?? ""}`,
    ),
    ...postsResp.data.map((entry) => `${siteUrl}/writing/${entry.slug ?? ""}`),
  ];

  return getServerSideSitemapIndexLegacy(ctx, [...urls]);
};

// Default export to prevent next.js errors
export default function SitemapIndex() {}
