import { FailedFetchPostsError } from "@/errors";
import DefaultLayout from "@/layouts/DefaultLayout/DefaultLayout";
import {
  fetchItems,
  fetchPosts,
  getTagsFromPosts,
} from "@/services/content-service";
import { NextSeo } from "next-seo";
import Link from "next/link";
import React from "react";

export async function getStaticProps() {
  const res = await fetchPosts(["title", "date_published", "tags", "slug"], {
    status: "published",
  });

  if (!res.ok) {
    throw new FailedFetchPostsError(await res.text());
  }

  const posts = (await res.json()).data;
  const tags = getTagsFromPosts(posts);

  return {
    props: {
      tags,
      posts,
    },
    revalidate: 60,
  };
}

export const Title = "Tags";

export default function Tags({ tags, posts }) {
  return (
    <DefaultLayout>
      <NextSeo
        title={Title}
        openGraph={{
          title: Title,
        }}
      />

      <h1>{Title}</h1>

      <section>
        {Object.keys(tags)
          .sort()
          .map((tag) => {
            const tagPosts = posts
              .filter((p) => p.tags.includes(tag))
              .sort((a, b) => b.title > -a.title);

            return (
              <React.Fragment key={tag}>
                <h2>{tag}</h2>
                <ul>
                  {tagPosts.map((post, _) => {
                    return (
                      <li key={post.slug}>
                        <Link href={`/writing/${post.slug}`}>{post.title}</Link>
                      </li>
                    );
                  })}
                </ul>
              </React.Fragment>
            );
          })}
      </section>
    </DefaultLayout>
  );
}
